<?php

/**
 * Gateway_Management controller.
 *
 * @category   Apps
 * @package    Gateway_Management
 * @subpackage Views
 * @author     DNSthingy <support@dnsthingy.com>
 * @copyright  2015-2017 DNSthingy
 * @license    All rights reserved
 * @link       https://www.dnsthingy.com
 */

///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

/**
 * Gateway_Management controller.
 *
 * @category   Apps
 * @package    Gateway_Management
 * @subpackage Controllers
 * @author     DNSthingy <support@dnsthingy.com>
 * @copyright  2015-2017 DNSthingy
 * @license    All rights reserved
 */

class Gateway_Management_Ajax extends ClearOS_Controller
{

    /**
     * Gateway_Management Ajax controller.
     */
    function __construct()
    {
        // Load dependencies
        //------------------
        $this->lang->load('gateway_management');
        $this->load->library('gateway_management/DNSthingy');

        // Send headers
        //-------------
        header('Cache-Control: no-cache, must-revalidate');
        header('Expires: Mon, 1 Jan 2000 00:00:00 GMT');
        header('Content-type: application/json');
    }

    /**
     * Gateway_Management default controller.
     *
     * @return void
     */
    function index()
    {
        $this->_404('Page does not exist');
    }

    /**
     * Retrieve json from another location.
     *
     * @param string $what info to request
     * @param string $arg  parameters needed for the request
     *
     * @return void
     */
    function dashboard()
    {
        $response = $this->dnsthingy->register();

        header($response['header']);
        echo $response['body'];
    }

    /**
     * Retrieve Gateway_Management subscription status.
     *
     * @return void
     */
    function subscription_status()
    {
        $this->dnsthingy->get_subscription_status();
    }

    /**
     * Suggest a blockpage IP.
     *
     * @return void
     */
    function suggest_ip()
    {
        $result = $this->dnsthingy->suggest_http_address();
        if ($result)
            echo '{"ip":"'.$result.'","msg": "Suggested IP.","status":"success"}';
        else
            echo '{"msg": "'.lang('gateway_management_suggest_ip_failed').'","status":"danger"}';
    }

    /**
     * Check blockpage IP address.
     *
     * @param string $ip IP for blockpage
     *
     * @return void
     */
    function validate_ip($ip)
    {
        $result = $this->dnsthingy->validate_http_address($ip);
        if ($result)
            echo '{"ip":"'.$ip.'","msg": "'.$result.'","color":"red"}';
        else
            echo '{"ip":"'.$ip.'","msg": "'.lang('gateway_management_blockpage_ip_available').'","color":"green"}';
    }

    /**
     * Returns a 404 response with message.
     *
     * @param string $message error message
     *
     * @return none
     */
    protected function _404($message=FALSE)
    {
        clearos_profile(__METHOD__, __LINE__);

        if (!$message) {
            $message = 'Page does not exist.';
        }

        header("HTTP/1.0 404 Not Found");
        echo '{"result":false,"message":"'.$message.'"}';
        exit;
    }
}
