<?php

/**
 * Gateway_Management settings controller.
 *
 * @category   Apps
 * @package    Gateway_Management
 * @subpackage Controllers
 * @author     DNSthingy <support@dnsthingy.com>
 * @copyright  2015-2017 DNSthingy
 * @license    All rights reserved
 * @link       https://www.dnsthingy.com
 */

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

class Gateway_Management_Settings extends ClearOS_Controller
{
    protected $basename = NULL;

    /**
     * Gateway Management settings constructor.
     * 
     * @param string $basename app basename
     */

    function __construct($basename)
    {
        $this->basename = $basename;
    }

    /**
     * General settings overview.
     *
     * @return view
     */

    function index()
    {
        $this->_view_edit('view');
    }

    /**
     * General settings edit view.
     *
     * @return view
     */

    function edit()
    {
        $this->_view_edit('edit');
    }

    /**
     * Common view/edit form
     *
     * @param string $form_type form type
     *
     * @return view
     */

    function _view_edit($form_type)
    {
        // Load libraries
        //---------------

        $this->load->library('gateway_management/DNSthingy');
        $this->load->library('network/Network');


        // Set validation rules
        //---------------------

        $this->form_validation->set_policy('enabled', 'gateway_management/DNSthingy', 'validate_enabled', FALSE);
        $this->form_validation->set_policy('http_address', 'gateway_management/DNSthingy', 'validate_http_address', TRUE);

        $form_ok = $this->form_validation->run();

        // Handle form submit
        //-------------------
        if (($this->input->post('submit') && $form_ok)) {
            try {
                $http_address = $this->input->post('http_address');
                $http_address_result = $this->dnsthingy->set_http_address($http_address);

                $enabled = (bool) $this->input->post('enabled');
                $enabled_result = $this->dnsthingy->set_enabled($enabled);

                if ($http_address_result && !$enabled_result) {
                    $this->dnsthingy->restart_daemons();
                }

                redirect('/' . $this->basename);
                return;
            } catch (Engine_Exception $e) {
                $this->page->view_exception($e->get_message());
                return;
            }
        }

        // Load view data
        //---------------

        try {
            // retrieve network mode in readable format
            // $network_modes = $this->network->get_supported_modes();
            // $network_mode = $network_modes[$this->network->get_mode()];

            // setup variables for view page
            $data['form_type'] = $form_type;
            $data['basename'] = $this->basename;
            $data['box_id'] = $this->dnsthingy->get_box_id();
            $data['gateway_mode'] = $this->dnsthingy->is_gateway();
            $data['enabled'] = $this->dnsthingy->is_enabled();
            $data['http_address'] = $this->dnsthingy->get_http_address();
            // $data['network_mode'] = $network_mode;
        } catch (Exception $e) {
            $this->page->view_exception($e);
            return;
        }

        // Load views
        //-----------

        $this->page->view_form('gateway_management/settings', $data, lang('base_settings'), $options);
    }
}
